import { FullGestureState } from '@use-gesture/react';
import { SlideActionType, SlideMode, TransitionSlideMode } from '../types/common';
declare type OnSlideStartChange<T> = {
    eventName: 'onSlideStartChange';
    slideActionType: SlideActionType;
    slideMode: T extends 'use-spring' ? SlideMode : TransitionSlideMode;
    nextItem: {
        index: number;
        id: string;
        startReached: boolean;
        endReached: boolean;
    };
};
declare type OnSlideChange<T> = {
    eventName: 'onSlideChange';
    slideActionType: SlideActionType;
    slideMode: T extends 'use-spring' ? SlideMode : TransitionSlideMode;
    currentItem: {
        index: number;
        id: string;
        startReached: boolean;
        endReached: boolean;
    };
};
declare type OnFullscreenChange = {
    eventName: 'onFullscreenChange';
    isFullscreen: boolean;
};
declare type OnDrag = Omit<FullGestureState<'drag'>, 'event'> & {
    eventName: 'onDrag';
    slideActionType: SlideActionType;
};
declare type OnLeftSwipe = {
    eventName: 'onLeftSwipe';
};
declare type OnRightSwipe = {
    eventName: 'onRightSwipe';
};
declare type SpringCarouselEvents<T> = OnSlideStartChange<T> | OnSlideChange<T> | OnDrag | OnFullscreenChange;
declare type TransitionCarouselEvents<T> = OnSlideStartChange<T> | OnSlideChange<T> | OnFullscreenChange | OnLeftSwipe | OnRightSwipe;
declare type Events<T> = T extends 'use-spring' ? SpringCarouselEvents<'use-spring'> : TransitionCarouselEvents<'use-transition'>;
declare type EventHandler<T> = (props: Events<T>) => void;
export declare type UseListenToCustomEvent<T> = {
    useListenToCustomEvent: (eventHandler: EventHandler<T>) => void;
    emitEvent: (event: Events<T>) => void;
};
export declare function useEventsModule<T extends 'use-spring' | 'use-transition'>(): {
    useListenToCustomEvent: (eventHandler: EventHandler<T>) => void;
    emitEvent: (event: Events<T>) => void;
};
export {};
