import { ReactNode } from 'react';
import { UseListenToCustomEvent } from '../modules/useEventsModule';
import { ItemWithThumb, ItemWithNoThumb, PrepareThumbsData } from '../types';
export declare type UseSpringReturnType = {
    carouselFragment: ReactNode;
    thumbsFragment: ReactNode;
    useListenToCustomEvent: UseListenToCustomEvent<'use-spring'>['useListenToCustomEvent'];
    getIsFullscreen(): boolean;
    enterFullscreen(ref?: HTMLElement): void;
    exitFullscreen(): void;
    slideToNextItem(): void;
    slideToPrevItem(): void;
    slideToItem(item: string | number): void;
    getIsActiveItem(id: string): boolean;
    getIsNextItem(id: string | number): boolean;
    getIsPrevItem(id: string | number): boolean;
};
export declare type UseSpringFreeScrollReturnType = {
    carouselFragment: ReactNode;
    thumbsFragment: ReactNode;
    useListenToCustomEvent: UseListenToCustomEvent<'use-spring'>['useListenToCustomEvent'];
    getIsFullscreen(): boolean;
    enterFullscreen(ref?: HTMLElement): void;
    exitFullscreen(): void;
    slideToNextItem(): void;
    slideToPrevItem(): void;
};
export declare type SlideType = 'fixed' | 'fluid';
export declare type SpringCarouselWithThumbs = {
    withThumbs: true;
    thumbsSlideAxis?: 'x' | 'y';
    items: ItemWithThumb[];
    prepareThumbsData?: PrepareThumbsData;
};
export declare type SpringCarouselWithNoThumbs = {
    withThumbs?: false | undefined;
    thumbsSlideAxis?: never;
    items: ItemWithNoThumb[];
    prepareThumbsData?: never;
};
export declare type SpringCarouselWithFixedItems = {
    slideType?: SlideType[0];
    itemsPerSlide?: number;
    startEndGutter?: number;
    initialActiveItem?: number;
};
export declare type SpringCarouselWithNoFixedItems = {
    slideType?: SlideType[1];
    itemsPerSlide?: never;
    startEndGutter?: never;
    initialActiveItem?: never;
};
export declare type SpringCarouselWithLoop = {
    withLoop: true;
    initialStartingPosition: 'start' | 'center' | 'end';
};
export declare type SpringCarouselWithNoLoop = {
    withLoop?: false | undefined;
    initialStartingPosition?: never;
};
export declare type SpringCarouselFreeScroll = {
    freeScroll: true;
    withLoop?: never;
    slideType?: never;
    enableFreeScrollDrag?: true;
    initialActiveItem?: never;
    itemsPerSlide?: never;
    animateWhenActiveItemChange?: never;
};
export declare type SpringCarouselNoFreeScroll = {
    freeScroll?: never | false | undefined;
    withLoop?: boolean;
    slideType?: SlideType;
    enableFreeScrollDrag?: never;
    initialActiveItem?: number;
    itemsPerSlide?: number;
    animateWhenActiveItemChange?: boolean;
};
export declare type BaseProps = {
    init?: boolean;
    gutter?: number;
    carouselSlideAxis?: 'x' | 'y';
    draggingSlideTreshold?: number;
    slideWhenThresholdIsReached?: boolean;
    disableGestures?: boolean;
    startEndGutter?: number;
};
declare type ScrollType<T> = T extends true ? SpringCarouselFreeScroll : SpringCarouselNoFreeScroll;
export declare type UseSpringCarouselWithThumbs<T> = BaseProps & SpringCarouselWithThumbs & ScrollType<T> & (SpringCarouselWithFixedItems | SpringCarouselWithNoFixedItems) & (SpringCarouselWithLoop | SpringCarouselWithNoLoop);
export declare type UseSpringCarouselWithNoThumbs<T> = BaseProps & SpringCarouselWithNoThumbs & ScrollType<T> & (SpringCarouselWithFixedItems | SpringCarouselWithNoFixedItems) & (SpringCarouselWithLoop | SpringCarouselWithNoLoop);
export declare type UseSpringCarouselWithFixedItems<T> = BaseProps & SpringCarouselWithFixedItems & ScrollType<T> & (SpringCarouselWithThumbs | SpringCarouselWithNoThumbs) & (SpringCarouselWithLoop | SpringCarouselWithNoLoop);
export declare type UseSpringCarouselWithNoFixedItems<T> = BaseProps & SpringCarouselWithNoFixedItems & ScrollType<T> & (SpringCarouselWithThumbs | SpringCarouselWithNoThumbs) & (SpringCarouselWithLoop | SpringCarouselWithNoLoop);
export declare type UseSpringCarouselWithFreeScroll = BaseProps & SpringCarouselFreeScroll & (SpringCarouselWithThumbs | SpringCarouselWithNoThumbs);
export declare type UseSpringCarouselComplete = BaseProps & (SpringCarouselWithThumbs | SpringCarouselWithNoThumbs) & (SpringCarouselWithFixedItems | SpringCarouselWithNoFixedItems) & (SpringCarouselWithLoop | SpringCarouselWithNoLoop) & (SpringCarouselFreeScroll | SpringCarouselNoFreeScroll);
export {};
